View source: R/dual_reg_parc.R
| dual_reg_parc | R Documentation |
Multiple regression for parcel data
dual_reg_parc(
BOLD,
parc,
parc_vals,
scale = c("local", "global", "none"),
scale_sm_xifti = NULL,
scale_sm_FWHM = 2,
TR = NULL,
hpf = 0.01,
GSR = FALSE
)
BOLD |
Subject-level fMRI data matrix ( |
parc |
The parcellation as an integer vector. |
parc_vals |
The parcel values (keys) in desired order, e.g.
|
scale |
|
scale_sm_xifti, scale_sm_FWHM |
Only applies if |
TR |
The temporal resolution of the data, i.e. the time between volumes,
in seconds. |
hpf |
The frequency at which to apply a highpass filter to the data
during pre-processing, in Hertz. Default: The highpass filter serves to detrend the data, since low-frequency variance is associated with noise. Highpass filtering is accomplished by nuisance regression of discrete cosine transform (DCT) bases. Note the |
GSR |
Center BOLD across columns (each image)? This
is equivalent to performing global signal regression. Default:
|
A list containing
the subject-level independent components S (Q \times V),
and subject-level mixing matrix A (TxQ).
templateICAr has been superseded by BayesBrainMap. For the core functions:
estimate_template: now estimate_prior in BayesBrainMap.
export_template: now export_prior in BayesBrainMap.
templateICA: now fit_BBM in BayesBrainMap.
activations: now engagements in BayesBrainMap.
and for the helper functions:
norm_BOLD: updated and moved to fMRItools.
dual_reg: updated and moved to fMRItools.
dual_reg_parc: updated and moved to fMRItools.
dual_reg2: updated in BayesBrainMap.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.