Applicable to a single latent field, or multiple latent fields if common smoothness is assumed
loglik_kappa_est(par, delta, D_diag, mesh, C1 = 1/(4 * pi), Q = NULL)Value of negative log likelihood
Vector of length two containing values of log kappa and log residual variance at which to compute log likelihood
Estimate of delta (subject effect or deviation)
Diagonal values of D matrix (template standard deviations)
Object of class "templateICA_mesh" containing the triangular mesh (see make_mesh)
For the unit variance case, \(\tau^2 = C1/\kappa^2\), where \(C1 = 1/(4\pi)\) when \(\alpha=2\), \(\nu=1\), \(d=2\)
Equal to the number of ICs for the common smoothness model, or NULL for the IC-specific smoothness model
Compute log-likelihood of kappa given an initial estimate of delta