Estimate variance decomposition and templates from DR estimates.
estimate_template_from_DR(DR, LV = NULL)List of two elements: the templates and the variance decomposition.
There are two version of the variance template: varUB gives the
unbiased variance estimate, and varNN gives the upwardly-biased
non-negative variance estimate. Values in varUB will need to be
clamped above zero before using in templateICA.
the test/retest dual regression estimates, as an array with dimensions \(M \times N \times (L \times V)\), where \(M\) is the number of visits (2), \(N\) is the number of subjects, \(L\) is the number of IC networks, and \(V\) is the number of data locations.
(\(L\) and \(V\) are collapsed because they are treated equivalently in the context of calculating the variance decomposition and templates).
A length-two integer vector giving the dimensions \(L\) and
\(V\) to reshape the result. Default: NULL (do not reshape the
result).